find_vmlinuz_initrd_duplicate

Function find_vmlinuz_initrd_duplicate 

pub(crate) fn find_vmlinuz_initrd_duplicate(
    storage: &Storage,
    digest: &str,
) -> Result<Option<String>>
Given the SHA256 sum of current VMlinuz + Initrd combo, find boot entry with the same SHA256Sum

Returns

Returns the directory name that has the same sha256 digest for vmlinuz + initrd as the one that’s passed in